import { UmiError } from '@metaplex-foundation/umi';

/** @category Errors */
class DataViewSerializerError extends UmiError {
  name = 'DataViewSerializerError';
  constructor(message, cause) {
    super(message, 'plugin', 'DataView Serializer', cause);
  }
}
class OperationNotSupportedError extends DataViewSerializerError {
  name = 'OperationNotSupportedError';
  constructor(operation) {
    super(`The operation [${operation}] is ` + `not supported by the DataView Serializer.`);
  }
}
class DeserializingEmptyBufferError extends DataViewSerializerError {
  name = 'DeserializingEmptyBufferError';
  constructor(serializer, toleratedDefaultValue) {
    super(`Serializer [${serializer}] cannot deserialize empty buffers.`);
    this.toleratedDefaultValue = toleratedDefaultValue;
  }
}
class NotEnoughBytesError extends DataViewSerializerError {
  name = 'NotEnoughBytesError';
  constructor(serializer, expected, actual) {
    super(`Serializer [${serializer}] expected ${expected} bytes, got ${actual}.`);
  }
}
class NumberOutOfRangeError extends DataViewSerializerError {
  name = 'NumberOutOfRangeError';
  constructor(serializer, min, max, actual) {
    super(`Serializer [${serializer}] expected number to be between ${min} and ${max}, got ${actual}.`);
  }
}

export { DataViewSerializerError, DeserializingEmptyBufferError, NotEnoughBytesError, NumberOutOfRangeError, OperationNotSupportedError };
//# sourceMappingURL=errors.mjs.map
